self.__precacheManifest = [
  {
    "revision": "2fc4a2753854405d6dfd",
    "url": "/static/css/main.f0a80c5d.chunk.css"
  },
  {
    "revision": "2fc4a2753854405d6dfd",
    "url": "/static/js/main.2b2d99ed.chunk.js"
  },
  {
    "revision": "42ac5946195a7306e2a5",
    "url": "/static/js/runtime~main.a8a9905a.js"
  },
  {
    "revision": "b7be88b1b0ecca52b711",
    "url": "/static/js/2.f0e785e4.chunk.js"
  },
  {
    "revision": "3bc4230ce7fa319b4dbbd8536c672645",
    "url": "/index.html"
  }
];