@import url(https://fonts.googleapis.com/css?family=Roboto+Mono|Roboto);body{margin:0;padding:0;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen,Ubuntu,Cantarell,Fira Sans,Droid Sans,Helvetica Neue,sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}code{font-family:source-code-pro,Menlo,Monaco,Consolas,Courier New,monospace}body{font-family:Roboto,sans-serif}#controls{color:#e6e6fa;background-color:rgba(0,0,0,.67);z-index:100;position:absolute;right:0;border:1px solid rgba(176,196,222,.2);width:256px;font-size:12px}#controls .item label{padding:10px;min-width:256px;display:block}#controls .item label:hover{cursor:pointer;background-color:rgba(176,196,222,.07)}header{background-color:#000a12;padding-left:20px;padding-top:6px;padding-bottom:4px;height:64px}header h1{color:#f5f5f5;font-size:32px;padding:0!important;margin:0!important}header h1.offline{color:#cd5c5c}header h1 span{color:#4682b4;font-size:14px}header>span{color:#b0c4de;font-style:italic;font-size:12px;padding:0!important;margin:0!important}.grid{display:grid;min-height:calc(100vh - 74px)}nav{grid-column:1/2;color:#f5f5f5;grid-row:1/12;background-color:#000a12}nav div{font-weight:700;padding:8px 8px 8px 18px;font-size:14px}nav a{text-decoration:none;color:#b0c4de}nav a:hover{color:#4682b4}main{position:relative;grid-column:2/12;grid-row:1/12;background-color:#000;font-family:Roboto Mono,monospace;overflow:auto;max-height:calc(100vh - 74px)}.std{font-size:12px;overflow-x:hidden}.std.err{color:#e53935}.std.out{color:#f5f5f5}
/*# sourceMappingURL=main.f0a80c5d.chunk.css.map */